#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

package Vhffs::Group;

#Vhffs::Group written by sod` <dieu AT gunnm DOT org>
use base qw(Vhffs::Object);

use strict;
use DBI;


sub new
{
    my $groupname;
    my $owner;
    my $this;
    my $class;
    my $self;
    my $princ;
    my $user;
    my $gid;

    $class       = shift;
    $princ       = shift;
    $groupname   = shift;
    $owner       = shift;
    $gid         = shift;
    
    $this={};
    
    $groupname = get_name_by_gid( $princ , $gid ) if( ( defined $gid ) && ( $gid =~ /[\d]+/ ) );
    
    return undef if( ! ( defined $groupname  ) );
    return undef if( ! ( $groupname =~ /^[a-z0-9]+$/ ) );
    return undef if( length( $groupname ) < 3 );
    
    $this = $class->SUPER::new( $princ , 0 , $owner );
    
    
    $this->{'groupname'} = $groupname if ( defined $groupname );
    $this->{'gid'} = $gid;
    
    bless( $this , $class );
    
}






# Simply get a unix group. In other words, only the gid and the groupname are fetched 
# fetch_unix is not used any more
sub fetch_unix
{
    my $request;
    my $result;
    my $self;
    my $query;

    $self = shift;
 
    $request = "SELECT * FROM vhffs_groups where groupname='$self->{'groupname'}'" if ( defined $self->{'groupname'} );
#    $request = "SELECT * FROM vhffs_groups where gid='$self->{'gid'}'" if ( defined $self->{'gid'} );

    $result = $self->{'db'}->{'DB_READ'}->prepare($request) or return -1;    
    $result->execute() or return -1;

    return -1 if ( $result->rows != 1 );

    foreach ( keys %{$result} )
    {
	    $self->{$_} = $result->{$_};
    }

    return 1;
}



# Simply get a complete group with intos
sub fetch
{
    my $groupname;
    my $request;
    my $result;
    my $request2;
    my $result2;
    my $self;
    my $query;
    my $hash;

    $self = shift;


    $request = "SELECT * FROM vhffs_groups where groupname='$self->{'groupname'}'";
    
    $result = $self->{'db'}->{'DB_READ'}->prepare($request) or return -1;    
    my $rows = $result->execute() or return -1;
    
    return -1 if ( $rows == 0 );
    
    
    $hash = $result->fetchrow_hashref();
    
    foreach ( keys %{$hash} )
    {
	$self->{$_} = $hash->{$_};
    }
    
    
    $request2 = "SELECT * FROM vhffs_groups_info where gid='$self->{'gid'}'";
    
    
    $result2 = $self->{'db'}->{'DB_READ'}->prepare($request2) or return -1;    
    $result2->execute() or return -1;
    $hash = $result2->fetchrow_hashref();

    foreach ( keys %{$hash} )
    {
		#Fix DB bug, quota and quota_used is in vhffs_groups and vhffs_groups_info
		next if( $_ eq "quota");
		next if( $_ eq "quota_used");
	    $self->{$_} = $hash->{$_};
    }


	return -2 if( $self->SUPER::fetch < 0 );

	$self->{group}	=	$self;

    return 1;
}







# get all unix groups and return it as an hashref
#THIS IS NOT A METHOD IT'S JUST A FUNCTION
sub get_all_unix
{
    my $dbh;
    my $request;
    my $result;
    
    $dbh = shift;

    $result = $dbh->selectall_hashref("SELECT * FROM vhffs_groups" , "gid" ) || die( "cannot fetch all groups" );

    return $result;    
}



#create a new group with the name given in parameter
sub create
{
    my $self;
    my $config;
    my $conf;
    my $result;
    my $request;
    my $gid;
    my $owneruid;
    my $query;
    my $badgroups;
    my $oid;
	my $rows;
	my $quota;


    $self = shift;

    
    $conf = $self->{'main'}->get_config->get_users;

    return -1 if ( ! defined $self->{'groupname'} );

	$self->{'groupname'} =~ tr/A-Z/a-z/;

    $badgroups = $self->{'main'}->get_config->get_bad_groupname;
    if( defined $badgroups )
    {

        foreach ( @{$badgroups} )
        {
            return -10 if ( $_ eq $self->{"groupname"} );
        }
    }



    #default init
    $self->{'gid'} = $conf->{'mingid'};
    
    #first, we check if the group doesn't exists
	$query ="SELECT * FROM vhffs_groups WHERE groupname= '" .$self->{'groupname'}."'";
    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
    $rows = $request->execute;

	return -1 if ( $rows > 0 );

    #Create the related object
    $oid = $self->SUPER::create;
    
    return -1 if ( $oid lt 0 );



	#Quota initialization
	#One day, god decide that : "10Mb ? It will be enough for everyone"
	#							"God smoke too much herb"
	$quota = 10;
	$quota = $conf->{'default_quota'} if( ( defined $conf ) && ( defined $conf->{'default_quota'} ) );
	$self->{'quota'} 		= $quota;
	$self->{'quota_used'} 	= $quota;


	
    # compute the gid
    $self->{'gid'} = $conf->{'mingid'};
    $result = $self->{'db'}->{'DB_READ'}->selectall_arrayref("SELECT MAX(gid) FROM vhffs_groups");
    $gid = $result->[0][0] + 1 if( $result->[0][0] );
    $self->{'gid'} =  $gid if ( ( $gid ) && ( $gid > $conf->{'mingid'}) );


    #finally, create the group
	$query = "INSERT INTO vhffs_groups VALUES('" . $self->{'gid'} . "' , '" . $self->{'groupname'} . "' , NULL , '".$quota."' , '".$quota."' , '$oid')";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query ) or return -2;
    $request->execute() or return -3;


	$query = "INSERT INTO vhffs_groups_info VALUES( '" . $self->{'gid'} ."' , '".$self->{'owner_uid'}."' , '".$self->{'owner_uid'}."')";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query) or return -2;
    $request->execute() or return -3;

    $self->commit;

    return $self->{'gid'};
}


sub remove_user_from_group
{
	use Vhffs::Constants;

	my $self = shift;
	my $user = shift;

	my $query;
	my $request;
	my $rows;

	$query ="SELECT * FROM vhffs_user_group WHERE gid= '" .$self->{'gid'}."' AND uid='".$user->get_uid."'";
	$request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	$rows = $request->execute;

	return -1 if ( $rows == 0 );

	$query = "UPDATE vhffs_user_group SET state='".Vhffs::Constants::TO_DELETE."' WHERE gid= '" .$self->{'gid'}."' AND uid='".$user->get_uid."'";
	$request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	$request->execute;
	
	return 1;


}



sub commit
{
    my $self = shift;

#    $self->{'quota'} = $self->{'main'}->get_config->get_users->{'default_quota'} if ( ! defined $self->{'quota'} );
 #   $self->{'quota_used'} = $self->{'quota'} if ( ! defined $self->{'quota_used'} );
   
    my $request_unix = "UPDATE vhffs_groups SET quota='".$self->{'quota'}."', quota_used='".$self->{'quota_used'}."' WHERE gid=".$self->{'gid'};

    $self->{'uid_mod'} = $self->{'owner_uid'} if ( !defined $self->{'uid_mod'} );

    my $request_info = "UPDATE vhffs_groups_info SET owner_uid = '".$self->{'owner_uid'}."', uid_mod = '".$self->{'uid_mod'}."' WHERE gid=".$self->{'gid'};
    my $result_unix = $self->{'db'}->{'DB_WRITE'}->prepare($request_unix);
    my $result_info = $self->{'db'}->{'DB_WRITE'}->prepare($request_info);

    $result_unix->execute or return -1;
    $result_info->execute or return -1;

    #Exec the super method !
    return -2 if( $self->SUPER::commit < 0 );

	return 1;
}



sub is_empty
{
	my $self = shift;
	return -1 if( ! defined $self);
	my $config = $self->{'main'}->get_config;

	my $rows;
	my $query;
	my $request;

	if( $config->use_web == 1 )
	{
		$query ="SELECT * FROM vhffs_httpd WHERE owner_gid='".$self->get_gid."'";
	    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	    $rows = $request->execute;
		return 0 if( $rows != 0 );
	}
	
	if( $config->use_cvs == 1 )
	{
		$query ="SELECT * FROM vhffs_cvs WHERE owner_gid='".$self->get_gid."'";
	    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	    $rows = $request->execute;
		return 0 if( $rows != 0 );
	}
	
	if( $config->use_svn == 1 )
	{
		$query ="SELECT * FROM vhffs_svn WHERE owner_gid='".$self->get_gid."'";
	    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	    $rows = $request->execute;
		return 0 if( $rows != 0 );
	}

	
	if( $config->use_mail == 1 )
	{
		$query ="SELECT * FROM vhffs_mxdomain WHERE owner_gid='".$self->get_gid."'";
	    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	    $rows = $request->execute;
		return 0 if( $rows != 0 );
	}


	if( $config->use_dns == 1 )
	{
		$query ="SELECT * FROM vhffs_dns_global WHERE owner_gid='".$self->get_gid."'";
	    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	    $rows = $request->execute;
		return 0 if( $rows != 0 );
	}



	if( $config->use_postgres == 1 )
	{
		$query ="SELECT * FROM vhffs_pgsql WHERE owner_gid='".$self->get_gid."'";
	    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	    $rows = $request->execute;
		return 0 if( $rows != 0 );
	}




	if( $config->use_mysql == 1 )
	{
		$query ="SELECT * FROM vhffs_mysql WHERE owner_gid='".$self->get_gid."'";
	    $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	    $rows = $request->execute;
		return 0 if( $rows != 0 );
	}

	return 1;

}

sub is_user_in_group
{
	my $self = shift;
	my $user = shift;
	my $query ="SELECT * FROM vhffs_user_group WHERE gid='".$self->get_gid."' AND uid='".$user->get_uid."'";
    my $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;
	return 1 if( $rows == 1 );
	return -1;
}


#Delete a group in the database
sub delete
{
    my $self;
    my $request;
    my $request2;
    my $request3;

    $self = shift;

    return 2 if ( $self->fetch < 0 );
    
    
    $request = $self->{'db'}->{'DB_WRITE'}->prepare("DELETE FROM vhffs_groups WHERE gid='".$self->{'gid'}."'");
    $request2 = $self->{'db'}->{'DB_WRITE'}->prepare("DELETE FROM vhffs_user_group WHERE gid='".$self->{'gid'}."'");
    $request3 = $self->{'db'}->{'DB_WRITE'}->prepare("DELETE FROM vhffs_groups_info WHERE gid='".$self->{'gid'}."'");
    
    $request->execute() or return -1;
    $request2->execute() or return -2;
    $request3->execute() or return -2;    
    
    $self->SUPER::delete;

    return 1;
}



#modify a group
#use it as modify_user, but with the fields of the vhfs_groups table
sub modify
{
    my $request;
    

    my ( $self , $field , $value ) = @_;
    
    $self->{$field} = $value;

    if( $field eq "groupname" )
    {
	    # VERIFY IF THE GROUP EXISTS FIX IT NOW
	    $request = $self->{'db'}->{'DB_WRITE'}->prepare("UPDATE vhffs_groups SET groupname=$value WHERE gid='$self->{'gid'}'");
    }
    else
    {
	    $request = $self->{'db'}->{'DB_WRITE'}->prepare("UPDATE vhffs_groups SET $field='$value' WHERE gid='$self->{'gid'}'");
    }   
    $request->execute() or return -1;
    
    return 1;
}


sub add_user
{
	my( $self , $user ) = @_;

	return -1 if( $user->fetch < 0 );

	my $query = "INSERT INTO vhffs_user_group VALUES('" . $user->{'uid'} . "' , '" . $self->{'gid'} . "' , '".Vhffs::Constants::WAITING_FOR_CREATION."')";
    my $request = $self->{'db'}->{'DB_WRITE'}->prepare( $query ) or return -2;
    $request->execute() or return -3;

	return 1;
	
}

sub set_quota
{
	my $self = shift;
	my $value = shift;
	$self->{'quota'} = $value;
}


sub set_quota_used
{
	my $self = shift;
	my $value = shift;
	$self->{'quota_used'} = $value;
}



sub get_quota_used
{
	my $self = shift;
	return $self->{'quota_used'};
}




sub get_quota
{
	my $self = shift;
	return $self->{'quota'};
}

sub get_groupname
{
    my $self = shift;
    return $self->{'groupname'};
}

sub get_gid
{
    my $self = shift;
    return $self->{'gid'};
}


sub get_name_by_gid
{
	my $main = shift;
	my $gid = shift;
	my $request = $main->{'db'}->{'DB_READ'}->prepare("SELECT groupname FROM vhffs_groups where gid='".$gid."'") or return -2;
	my $rows = $request->execute();

	if( $rows == 0 )
	{
		return( "nobody" );
	}
	else
	{
		my $result = $request->fetchrow_hashref();
		return( $result->{groupname} );
	}

}


sub get_owner_username
{
	my $self = shift;
	my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_users where uid='".$self->{'owner_uid'}."'") or return -2;
	my $rows = $request->execute();

	if( $rows == 0 )
	{
		return( "nobody" );
	}
	else
	{
		my $result = $request->fetchrow_hashref();
		return( $result->{username} );
	}
	
}




sub set_owner_username
{
	my( $self , $username ) = @_;

	my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_users where username='".$username."'") or return -2;
	my $rows = $request->execute;

	if( $rows == 0 )
	{
		return -1;
	}
	else
	{
		my $result = $request->fetchrow_hashref();
		$self->{'owner_uid'} = $result->{'uid'};
	}
}

sub get_owneruid
{
	my $self = shift;
	if( defined $self->{'owner_uid'} )
	{
		return $self->{'owner_uid'};
	}
	else
	{
		return undef;
	}

}


sub get_last_groups
{   
    my $vhffs = shift;
    
    return if ( !defined $vhffs );
   	my @groups; 
    my $query = "SELECT groupname FROM vhffs_groups WHERE groupname NOT IN (SELECT username FROM vhffs_users) ORDER BY vhffs_groups.gid DESC LIMIT 10";
    my $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );                                             $request->execute;
    while( my $row = $request->fetchrow_arrayref )
    {
        my $group = new Vhffs::Group( $vhffs , $row->[0]   , '401' );
        if( $group->fetch > 0 )
        {                                                                                                             push @groups , $group;
        }
    }
    return \@groups;
}


sub get_users
{
	use Vhffs::User;
    my $self = shift;

    return undef if( $self->fetch < 0 );
    my @users;
    my $gid = $self->get_gid;
    my $query = "SELECT u.username FROM vhffs_users u, vhffs_user_group ug WHERE ug.gid='".$gid."' AND u.uid=ug.uid";
    my $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
    $request->execute;
    while( my $row = $request->fetchrow_arrayref )
    {
        my $user = new Vhffs::User( $self->{'main'} , $row->[0] , '401' );
        push( @users , $user ) if( $user->fetch );
    }
    return \@users;
}

sub get_owner
{
	my $self = shift;

	if( ! defined $self->{'user'} )
	{
		$self->{'user'} = new  Vhffs::User( $self->{'main'} , undef , $self->{'owner_uid'} );
		$self->{'user'}->fetch if( defined $self->{'user'} );
	}

	return( $self->{'user'} );

}

sub getall_by_user
{
    my $vhffs = shift;
    my $state = shift;
    my $user = shift;
	my $name;	
	return undef if( $user->fetch < 0 );

    my $db = $vhffs->get_db_object;
    my @result;
    my $query = "SELECT groupname FROM vhffs_groups g, vhffs_object o , vhffs_user_group ug WHERE ug.gid=g.gid AND g.object_id=o.object_id AND g.groupname NOT IN (SELECT username FROM vhffs_users ) AND ug.uid=".$user->get_uid;

    $query .= " AND o.state=$state " if( defined $state );
    $query .= " ORDER BY g.groupname";

    my $request = $db->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows <= 0 );

    my $names = $request->fetchall_arrayref;

    my $group;
    foreach $name ( @{$names} )
    {

        $group = new Vhffs::Group( $vhffs , $name->[0] , '401' );
        push( @result , $group) if( $group->fetch > 0 );
    }
    return \@result;
}


sub getall
{
	my $vhffs = shift;
	my $state = shift;
	my $name = shift;

	my $db = $vhffs->get_db_object;
	my @result;	
	my $query = "SELECT groupname FROM vhffs_groups g, vhffs_object o WHERE g.object_id=o.object_id AND g.groupname NOT IN (SELECT username FROM vhffs_users )  ";
	
	$query .= " AND o.state=$state " if( defined $state );
	$query .= " AND g.groupname LIKE '%".$name."%' " if( defined $name );

	$query .= " ORDER BY g.groupname";

	my $request = $db->{'DB_READ'}->prepare( $query );
	my $rows = $request->execute;

	return undef if( $rows <= 0 );
	
	my $names = $request->fetchall_arrayref;

	my $group;
	foreach $name ( @{$names} )
	{
		
		$group = new Vhffs::Group( $vhffs , $name->[0] , '401' );
		push( @result , $group) if( $group->fetch > 0 );
    }
    return \@result;
}

sub getall_by_letter
{
    my $vhffs = shift;
    my $letter = shift;
    my $state = shift;

    return getall($vhffs, $state) if(! defined $letter );
    $letter .= '%';

    my $db = $vhffs->get_db_object;
    my @result;
    my $query = 'SELECT groupname FROM vhffs_groups g INNER JOIN vhffs_object o ON g.object_id=o.object_id LEFT OUTER JOIN vhffs_users u ON u.username = g.groupname WHERE u.username IS NULL AND g.groupname LIKE ?';
    $query .= "AND o.state=$state " if( defined $state );
    
    my $request = $db->{'DB_READ'}->prepare( $query );
    return undef if( ! $request->execute( $letter ) );

    my $names = $request->fetchall_arrayref;

    my $group;
    foreach my $name ( @{$names} )
    {   

        $group = new Vhffs::Group( $vhffs , $name->[0] , '401' );
        push( @result , $group) if( $group->fetch > 0 );
    }
    return \@result;

}

1;
