#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Panel::User;

use DBI;
use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use strict;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;

sub get_last_users
{
	my $vhffs = shift;
	my @users;

	return if ( !defined $vhffs );

	my $query = "SELECT username FROM vhffs_users ORDER BY uid LIMIT 0,10";
    my $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );

	while( my $hash =  $request->fetchrow_hashref )
	{
		my $user = new Vhffs::Users( $vhffs , $hash->{username} , '401' );	
		if( $user->fetch > 0 )
		{
			push @users , $user;
		}
	}
	return \@users;

}

sub getall_users
{
	my $main = shift;
	my $name = shift;

	my $query;

    if( ! defined $name )
	{
		$query = "SELECT u.username, ui.firstname, ui.lastname , o.object_id FROM vhffs_users u, vhffs_user_info ui, vhffs_object o WHERE o.object_id=u.object_id AND u.uid=ui.uid";
	}
	else
	{
		$query = "SELECT u.username, ui.firstname, ui.lastname , o.object_id FROM vhffs_users u, vhffs_user_info ui, vhffs_object o WHERE o.object_id=u.object_id AND u.uid=ui.uid AND ( ( u.username LIKE '%".$name."%' ) OR (ui.firstname LIKE '%".$name."%' ) OR (ui.lastname LIKE '%".$name."%') )";
	}

	
    my $request = $main->{'db'}->{'DB_READ'}->prepare( $query );

    return undef if ( $request->execute <= 0 );
    return( $request->fetchall_hashref('username') );

}

sub set_lang
{
	my $user = shift;
	my $lang = shift;
	
	return -1 if ( ( ! defined $user ) || ( ! defined $lang ) );

	return -2 if( $user->fetch < 0 );

	my $uid = $user->get_uid;

	my $query = "SELECT * FROM vhffs_panel_user_prefs WHERE uid='".$uid."'";
	my $request = $user->{'db'}->{'DB_READ'}->prepare( $query );
	my $rows = $request->execute;

	if( $rows != 0 )
	{
		$query = "UPDATE vhffs_panel_user_prefs SET language='".$lang."' WHERE uid='".$uid."'";
	}
	else
	{
		$query = "INSERT INTO vhffs_panel_user_prefs VALUES( '".$uid."' , '".$lang."' , '' )";
	}
	$request = $user->{'db'}->{'DB_WRITE'}->prepare( $query );
	$request->execute or return -4;
}


sub set_theme
{
	my $user = shift;
	my $theme = shift;
	
	return -1 if ( ( ! defined $user ) || ( ! defined $theme ) );

	return -2 if( $user->fetch < 0 );

	my $uid = $user->get_uid;

	my $query = "SELECT * FROM vhffs_panel_user_prefs WHERE uid='".$uid."'";
	my $request = $user->{'db'}->{'DB_READ'}->prepare( $query );
	my $rows = $request->execute;

	if( $rows != 0 )
	{
		$query = "UPDATE vhffs_panel_user_prefs SET theme='".$theme."' WHERE uid='".$uid."'";
	}
	else
	{
		$query = "INSERT INTO vhffs_panel_user_prefs VALUES( '".$uid."' , '', '".$theme."' )";
	}
	$request = $user->{'db'}->{'DB_WRITE'}->prepare( $query );
	$request->execute or return -4;
}

sub get_lang
{
	my $user = shift;
	return -1 if( ! defined $user );

	return -2 if( $user->fetch < 0 );

	my $uid = $user->get_uid;

	my $query = "SELECT language FROM vhffs_panel_user_prefs WHERE uid='".$uid."'";
	my $request = $user->{'db'}->{'DB_READ'}->prepare( $query );
	my $rows = $request->execute;

	if( $rows == 0 )
	{
		return Vhffs::Constants::DEFAULT_LANG;
	}
	else
	{
		my $value = $request->fetchrow_arrayref;
		return $value->[0];
	}
	
}


sub get_theme
{
	my $user = shift;
	return -1 if( ! defined $user );

	return -2 if( $user->fetch < 0 );

	my $uid = $user->get_uid;

	my $query = "SELECT theme FROM vhffs_panel_user_prefs WHERE uid='".$uid."'";
	my $request = $user->{'db'}->{'DB_READ'}->prepare( $query );
	my $rows = $request->execute;

	if( $rows == 0 )
	{
		return Vhffs::Constants::DEFAULT_THEME;
	}
	else
	{
		my $value = $request->fetchrow_arrayref;
		return $value->[0];
	}
	
}

1;
