#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Robots::Mail;

use Vhffs::Services::Mail;
use Vhffs::Constants;
use Vhffs::Functions;


sub getall_refused
{
	my( $main ) = @_;
	
	my $query = "SELECT m.domain, m.object_id FROM  vhffs_mxdomain m, vhffs_object o WHERE o.state='".Vhffs::Constants::VALIDATION_REFUSED."' AND m.object_id = o.object_id";

	$request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -2;
	return undef if ( $request->execute() <= 0 );

	return( $request->fetchall_hashref('domain') );
}


sub get_all_mail_to_create
{
	my( $main ) = @_;
	
	my $query = "SELECT m.domain, m.object_id FROM  vhffs_mxdomain m, vhffs_object o WHERE o.state='".Vhffs::Constants::WAITING_FOR_CREATION."' AND m.object_id = o.object_id";

	$request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -2;
	return undef if ( $request->execute() <= 0 );

	return( $request->fetchall_hashref('domain') );
	
}


sub get_all_mail_to_delete
{
	my( $main ) = @_;
	
	my $query = "SELECT m.domain, m.object_id FROM  vhffs_mxdomain m, vhffs_object o WHERE o.state='".Vhffs::Constants::TO_DELETE."' AND m.object_id = o.object_id";

	$request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -2;
	return undef if ( $request->execute() <= 0 );

	return( $request->fetchall_hashref('domain') );
	
}


sub delete_mail
{
	my ( $main , $domain ) = @_;

	my $mail = new Vhffs::Services::Mail( $main , $domain );
	my $retour;	
	if( ($retour = $mail->fetch) > 0 )
	{
		$mail->add_history( "Will delete this mail domain" );
		$mail->delete;
	}
}


sub create_mail
{
	my ( $main , $domain ) = @_;

	my $mail = new Vhffs::Services::Mail( $main , $domain );
	my $retour;	
	if( ($retour = $mail->fetch) > 0 )
	{
		$mail->add_history( "Robots will activated this mail domain" );
		$mail->set_status( Vhffs::Constants::ACTIVATED );	
		$mail->commit;
	}
}


1;

