#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.



use POSIX;
use strict;
use locale;
use Locale::gettext;
use HTML::Template;
use CGI;
use CGI::Session;
use Vhffs::Main;
use Vhffs::Functions;
use Vhffs::Services::Mailing;
use Vhffs::Listengine::Listengine;
use Vhffs::Listengine::Panel;
use utf8;

my $template;
my $mail;
my $vhffs = init Vhffs::Main;

setlocale(LC_ALL, CGI->cookie("language") );
bindtextdomain("vhffs", $vhffs->get_config->get_intldir);
textdomain("vhffs");

my $cgi = new CGI;
my $listname = $cgi->param("list");
my $mid = $cgi->param("mid");
my( $lpart , $domain ) = split/\@/,$listname,2;
my $list = new Vhffs::Services::Mailing( $vhffs , $lpart , $domain );
my $templatedir = $vhffs->get_config->get_listengine_templatesdir;
my $theme = Vhffs::Listengine::Panel::check_theme( $cgi->cookie("theme") );

$template = new HTML::Template( filename => $templatedir."/error.tmpl");


if( Vhffs::Functions::valid_mail( $listname ) != 1 )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => gettext("Bad listname") );
}
elsif( ( ! defined $lpart ) || ( ! defined $domain ) )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => gettext("Error in listname") );
}
elsif( ( ! defined $list ) || ( $list->fetch < 0 ) )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => gettext("Undefined list") );

}
elsif( ( defined $mid ) && ( ! ( $mid =~ /^[a-zA-Z0-9]+$/ ) ) )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => gettext("Bad message-id") );

}
elsif( $list->get_open_archive != 1 )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => gettext("Archive are not open for this list") );

}
elsif( ! defined ( $mail = Vhffs::Listengine::Listengine::search_message( $list , $mid ) ) )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => sprintf( gettext("unknown message-id t: %s") , $mid ) );
}
else
{
    my $body = "";
    my $header = "";

    $header .= gettext("From: " ) . Vhffs::Listengine::Listengine::obscur_addrs( $mail->get('From') )."<br>";
    $header .= gettext("To: " ) . Vhffs::Listengine::Listengine::obscur_addrs( $mail->get('To') )."<br>";
    $header .= gettext("Cc: " ) . Vhffs::Listengine::Listengine::obscur_addrs( $mail->get('Cc') )."<br>";
    $header .= gettext("Subject: " ) . $mail->get('Subject');
    
    foreach ( @{$mail->body} )
	{
		if( ! utf8::is_utf8( $_ ) )
		{
			utf8::encode( $_ );
		}
		$body .=  $_  ."<br>";
    }
    $template = new HTML::Template( filename => $templatedir."/showmsg.tmpl");
    $template->param( TITLE => sprintf( gettext( "Message from list %s" ) , $list->get_listname ) );
    $template->param( THEME_NAME => $theme );
    $template->param( MAIL_HEADER => $header );
    $template->param( MAIL_BODY => $body );

}



print "Content-Type: text/html; charset=utf-8\n\n".$template->output;
