#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Httpd;
use Vhffs::Acl;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $template;

my $cgi          = $panel->{'cgi'};
my $vhffs        = $panel->{'vhffs'};
my $session      = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user         = $panel->{'user'};
my $group        = $panel->{'group'};

my $projectname = $session->param("project");


my $accept       = $cgi->param("ACCEPT");
my $reason       = $cgi->param("reason");

my $templatedir  = $vhffs->get_config->get_templatedir;

$template        = new HTML::Template( filename => $templatedir."/admin/misc/moderation_applied.tmpl" );

#Use is not allowed to see this page, only MODERATOR and ADMIN
if( ($user->is_moderator != 1 ) && ( $user->is_admin ) != 1 ) 
{
	my $message = gettext("You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
else
{
	use Vhffs::Object;
	my $oid = $cgi->param("OID");
	my $oidasker = $cgi->param("OID_ASKER");
	my $object = new Vhffs::Object( $vhffs , $oid , '401' );

	if( ( ! defined $oid ) || ( ! defined $object ) || ( ! defined $accept ) )
	{
		$template->param( MESSAGE  => gettext("CGI problem") );
	}
	elsif( $object->fetch < 0 )
	{
		$template->param( MESSAGE  => gettext("Cannot obtain information about this object") );
	}
	else
	{
		if( $accept == 1 )
		{
			$object->set_status( Vhffs::Constants::WAITING_FOR_CREATION );
			my $username = Vhffs::User::get_name_by_uid( $vhffs , $object->get_owner_uid );
			my $userbis = new Vhffs::User( $vhffs , $username , '401' );
			if( $userbis->fetch > 0 )
			{
			    my $mail;
			    $mail  = gettext("Your request on VHFFS was accepted\n");
			    $mail .= gettext("Please wait while we are creating your object\n");
			    $mail .= gettext("Cheers,")."\n";
			    $mail .= gettext("The Moderator and Admin team");

			    my $subject = gettext("Your request on VHFFS platform");
			    Vhffs::Functions::send_mail( $vhffs->get_config->get_moderator_mail , $userbis->get_mail , $subject , $mail );

	            if( $vhffs->get_config->use_notation == 1 )
				{
					use Vhffs::Note;
					Vhffs::Note::inc_note( $vhffs , $userbis , 1 );
				}

			}
		}
		else
		{
			my $askerobject = new Vhffs::Object( $vhffs , $oidasker , '401' );
			$askerobject->fetch;
		    $object->set_description( $reason );
		    $object->set_status( Vhffs::Constants::VALIDATION_REFUSED );
	        if( $vhffs->get_config->use_notation == 1 )
			{
				use Vhffs::Note;
				Vhffs::Note::inc_note( $vhffs , $askerobject , -1 );
			}
		}
		
		if( $object->commit < 0 )
		{
		    $template->param( MESSAGE  => gettext("Cannot apply modifications") );
		}
		else
		{
		    $template->param( MESSAGE  => gettext("Modifications applied successfully") );
		}
	}
}

set_refresh_url Vhffs::Panel::Main($panel, "/admin/moderation.pl", 0);
display Vhffs::Panel::Main($panel, $template->output);
