#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Httpd;
use Vhffs::Acl;
use Vhffs::Constants;
use Vhffs::Functions;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $oid = $cgi->param("OID");

$oid = $cgi->param("oid") if( ! defined $oid );

my $template;

my $object;
my $ok = 1;
my $title;

my $message;

$object = new Vhffs::Object( $vhffs , $oid , '401' );


my $templatesdir = $vhffs->get_config->get_templatedir;


if( ( ! defined $oid ) || ( ! defined $object ) )
{
	$template = new HTML::Template( filename => "$templatesdir/misc/simplemsg.tmpl" );
	$message = gettext( "CGI Error !");
	$template->param( MESSAGE => $message );
}
elsif( $object->fetch < 0 )
{

	$template = new HTML::Template( filename => "$templatesdir/misc/simplemsg.tmpl" );
	$message = gettext("Cannot get information on this object");
	$template->param( MESSAGE => $message );

}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $object , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) && ( $user->is_moderator != 1 ) )
{
	$template = new HTML::Template( filename => "$templatesdir/misc/simplemsg.tmpl" );
	$message = gettext("You're not allowed to view this object's ACL");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => "$templatesdir/misc/history.tmpl" );

	$template->param( TITLE => gettext("History") );

	my $subtemplate;
	my $history = $object->get_history;
	my $output = "";
	my $string;
	my $date;

	if( ! defined $history )
	{
		$template->param( HISTORY_PART => gettext("No event about this object") );
	}
	else
	{
		foreach( sort keys %{$history} )
		{
			$subtemplate = new HTML::Template( filename => "$templatesdir/misc/history_part.tmpl" );
			$date =  Vhffs::Functions::parse_date( $history->{$_}{date} );
			if( defined $date )
			{
				$string = $date->{day}."/".$date->{month}."/".$date->{year}." @ ".$date->{hours}.":".$date->{minutes}.":".$date->{seconds};
			}
			else
			{
				$string = gettext("no information about date");
			}
			$subtemplate->param( DATE => $string );
			$subtemplate->param( EVENT => $history->{$_}{message} );
			$output .= $subtemplate->output;
		}
		$template->param( HISTORY_PART => $output );
	}
}

display Vhffs::Panel::Main($panel, $template->output);
