#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use CGI;


my $vhffs = init Vhffs::Main;
my $cookie = Vhffs::Panel::Main::cookie_lang( $vhffs );
my $cgi = new CGI;
my $template;
my $subtemplate;
my $templatedir = $vhffs->get_config->get_templatedir;
my $group;
my $groups = Vhffs::Group::get_last_groups( $vhffs );
my $output_final="";
my $maintemplate = new HTML::Template( filename => $templatedir."/public/lastgroups.tmpl" );

my $hostname;
$hostname = $vhffs->get_config->get_host_name;
$hostname = "VHFFS" if( ! defined $hostname );


$maintemplate->param( THEME => Vhffs::Panel::Main::get_theme( $vhffs ) );
$maintemplate->param( TEXT_TITLE => sprintf( gettext("Last groups on %s") , $hostname ) );


foreach $group (@{$groups})
{
	$template = new HTML::Template( filename => $templatedir."/public/misc/lastgroups-part.tmpl" );

	$template->param( TEXT_TITLE => $group->get_groupname );

	$template->param( TEXT_GROUPNAME => gettext("Groupname") );
	$template->param( VALUE_GROUPNAME => $group->get_groupname );
	$template->param( TEXT_USERS => gettext("Users") );

	$template->param( TEXT_DESCRIPTION => gettext("Description") );
	$template->param( VALUE_DESCRIPTION => $group->get_description );
	
	my $output = "";
	my $users = $group->get_users;
	my $subtemplate;
	my $user;
	if( ! defined $users )
	{
		$template->param( VALUE_USERS => gettext("No group for this user") );
	}
	else
	{
		$subtemplate = new HTML::Template( filename => $templatedir."/public/user_part.tmpl" );
		
		foreach $user (@{$users})
		{
			$subtemplate->param( VALUE => $user->get_username );	
			$output .= $subtemplate->output;
		}

		$template->param( VALUE_USERS => $output );
	}
	$output_final .= $template->output;
}
$subtemplate = new HTML::Template( filename => $templatedir."/public/banner.tmpl" );
$subtemplate->param( BACK_PUBLIC => gettext( "Homepage of public area") );
$subtemplate->param( BACK_LOGIN => gettext( "Go on login page" ) );
$subtemplate->param( WEBSITE_LIST => gettext( "List of all websites" ) );
$subtemplate->param( LAST_GROUPS => gettext( "Last groups" ) );
$subtemplate->param( LAST_USERS => gettext( "Last users" ) );
$subtemplate->param( SEARCH => gettext( "Search:" ) );

$maintemplate->param( BANNER => $subtemplate->output );


$maintemplate->param( VALUES => $output_final );
print "Content-Type: text/html; charset=utf-8\n\n" . $maintemplate->output;
