#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

########################################################
# This robot make dump for each MySQL database
# and put it on each group directory
#

use Vhffs::Robots;


#################
#Config Stuff
my $MYSQLDUMP_BINARY = "/usr/bin/mysqldump";
#################

use strict;
use Vhffs::Main;
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Functions;
use Vhffs::Services::Mysql;

my $vhffs = init Vhffs::Main; 

Vhffs::Robots::lock( $vhffs );

my $objs  = Vhffs::Services::Mysql::getall( $vhffs  );
my $admin_dbuser = $vhffs->get_config->get_mysql_admin_username;
my $admin_dbpass = $vhffs->get_config->get_mysql_admin_pass;
my $admin_dbhost = $vhffs->get_config->get_mysql_admin_host;

my $obj;
my $group;
my $groupname;

if( ! -x $MYSQLDUMP_BINARY )
{
	print "Error, mysqldump is not present on this system\n";
	exit( -1 );
}

foreach $obj ( @{$objs} )
{
		$groupname = Vhffs::Group::get_name_by_gid( $vhffs , $obj->get_ownergid );
		my $dbname = $obj->get_dbname;
		my $dir = Vhffs::Functions::hash_groupname( $groupname , $vhffs );
		if( -d $dir )
		{
			my $file = $dir."/".$dbname.".mysql.dump";
			my $cmd = "$MYSQLDUMP_BINARY -u $admin_dbuser -h $admin_dbhost -p$admin_dbpass $dbname > $file";
			system( $cmd );

			#Change the chmod if the backup succeed
			if( -f $file )
			{
				chown( $obj->get_owneruid , $obj->get_ownergid , $file );
				chmod( 0660 , $file );
			}
			
		}
#	$group = new Vhffs::Group( $vhffs , Vhffs::Group::get_name_by_gid( $vhffs , $obj->get_ownergid ) );
}

Vhffs::Robots::unlock( $vhffs );

exit 0;
